diff --git a/lib/poptI.c b/lib/poptI.c
index 9aff685..e13e30d 100644
--- a/lib/poptI.c
+++ b/lib/poptI.c
@@ -12,8 +12,7 @@
 struct rpmInstallArguments_s rpmIArgs = {
     0,			/* transFlags */
     0,			/* probFilter */
-    0,			/* installInterfaceFlags */
-    0,			/* eraseInterfaceFlags */
+    0,			/* eiuInterfaceFlags */
     0,			/* qva_flags */
     0,			/* numRelocations */
     0,			/* noDeps */
@@ -46,7 +45,7 @@ static void installArgCallback( poptContext con,
     switch (opt->val) {
 
     case 'i':
-	ia->installInterfaceFlags |= INSTALL_INSTALL;
+	ia->eiuInterfaceFlags |= RPMEIU_INSTALL;
 	break;
 
     case POPT_EXCLUDEPATH:
@@ -131,7 +130,7 @@ struct poptOption rpmInstallPoptTable[] = {
   N_("install all files, even configurations which might otherwise be skipped"),
 	NULL},
  { "allmatches", '\0', POPT_BIT_SET,
-	&rpmIArgs.eraseInterfaceFlags, UNINSTALL_ALLMATCHES,
+	&rpmIArgs.eiuInterfaceFlags, RPMEIU_ALLMATCHES,
 	N_("remove all packages which match <package> (normally an error is generated if <package> specified multiple packages)"),
 	NULL},
 
@@ -149,7 +148,7 @@ struct poptOption rpmInstallPoptTable[] = {
 	N_("print dependency loops as warning"), NULL},
 
  { "erase", 'e', POPT_BIT_SET,
-	&rpmIArgs.installInterfaceFlags, INSTALL_ERASE,
+	&rpmIArgs.eiuInterfaceFlags, RPMEIU_ERASE,
 	N_("erase (uninstall) package"), N_("<package>+") },
  { "excludeconfigs", '\0', POPT_BIT_SET|POPT_ARGFLAG_DOC_HIDDEN,
 	&rpmIArgs.transFlags, RPMTRANS_FLAG_NOCONFIGS,
@@ -167,11 +166,11 @@ struct poptOption rpmInstallPoptTable[] = {
  { "force", '\0', 0, NULL, RPMCLI_POPT_FORCE,
 	N_("short hand for --replacepkgs --replacefiles"), NULL},
 
- { "freshen", 'F', POPT_BIT_SET, &rpmIArgs.installInterfaceFlags,
-	(INSTALL_UPGRADE|INSTALL_FRESHEN|INSTALL_INSTALL),
+ { "freshen", 'F', POPT_BIT_SET, &rpmIArgs.eiuInterfaceFlags,
+	(RPMEIU_UPGRADE|RPMEIU_FRESHEN|RPMEIU_INSTALL),
 	N_("upgrade package(s) if already installed"),
 	N_("<packagefile>+") },
- { "hash", 'h', POPT_BIT_SET, &rpmIArgs.installInterfaceFlags, INSTALL_HASH,
+ { "hash", 'h', POPT_BIT_SET, &rpmIArgs.eiuInterfaceFlags, RPMEIU_HASH,
 	N_("print hash marks as package installs (good with -v)"), NULL},
  { "ignorearch", '\0', POPT_BIT_SET,
 	&rpmIArgs.probFilter, RPMPROB_FILTER_IGNOREARCH,
@@ -206,7 +205,7 @@ struct poptOption rpmInstallPoptTable[] = {
 	N_("don't install file security contexts"), NULL},
 
  { "noorder", '\0', POPT_BIT_SET,
-	&rpmIArgs.installInterfaceFlags, INSTALL_NOORDER,
+	&rpmIArgs.eiuInterfaceFlags, RPMEIU_NOORDER,
 	N_("do not reorder package installation to satisfy dependencies"),
 	NULL},
 
@@ -257,7 +256,7 @@ struct poptOption rpmInstallPoptTable[] = {
 	N_("upgrade to an old version of the package (--force on upgrades does this automatically)"),
 	NULL},
  { "percent", '\0', POPT_BIT_SET,
-	&rpmIArgs.installInterfaceFlags, INSTALL_PERCENT,
+	&rpmIArgs.eiuInterfaceFlags, RPMEIU_PERCENT,
 	N_("print percentages as package installs"), NULL},
  { "prefix", '\0', POPT_ARG_STRING, &rpmIArgs.prefix, 0,
 	N_("relocate the package to <dir>, if relocatable"),
@@ -274,7 +273,7 @@ struct poptOption rpmInstallPoptTable[] = {
  { "test", '\0', POPT_BIT_SET, &rpmIArgs.transFlags, RPMTRANS_FLAG_TEST,
 	N_("don't install, but tell if it would work or not"), NULL},
  { "upgrade", 'U', POPT_BIT_SET,
-	&rpmIArgs.installInterfaceFlags, (INSTALL_UPGRADE|INSTALL_INSTALL),
+	&rpmIArgs.eiuInterfaceFlags, (RPMEIU_UPGRADE|RPMEIU_INSTALL),
 	N_("upgrade package(s)"),
 	N_("<packagefile>+") },
 
diff --git a/lib/rpminstall.c b/lib/rpminstall.c
index 4a972eb..8678b39 100644
--- a/lib/rpminstall.c
+++ b/lib/rpminstall.c
@@ -115,10 +115,10 @@ void * rpmShowProgress(const void * arg,
 
     case RPMCALLBACK_INST_START:
 	rpmcliHashesCurrent = 0;
-	if (h == NULL || !(flags & INSTALL_LABEL))
+	if (h == NULL || !(flags & RPMEIU_LABEL))
 	    break;
 	/* @todo Remove headerFormat() on a progress callback. */
-	if (flags & INSTALL_HASH) {
+	if (flags & RPMEIU_HASH) {
 	    s = headerFormat(h, "%{NAME}", NULL);
 	    if (isatty (STDOUT_FILENO))
 		fprintf(stdout, "%4d:%-23.23s", rpmcliProgressCurrent + 1, s);
@@ -136,11 +136,11 @@ void * rpmShowProgress(const void * arg,
 
     case RPMCALLBACK_TRANS_PROGRESS:
     case RPMCALLBACK_INST_PROGRESS:
-	if (flags & INSTALL_PERCENT)
+	if (flags & RPMEIU_PERCENT)
 	    fprintf(stdout, "%%%% %f\n", (double) (total
 				? ((((float) amount) / total) * 100)
 				: 100.0));
-	else if (flags & INSTALL_HASH)
+	else if (flags & RPMEIU_HASH)
 	    printHash(amount, total);
 	(void) fflush(stdout);
 	break;
@@ -149,9 +149,9 @@ void * rpmShowProgress(const void * arg,
 	rpmcliHashesCurrent = 0;
 	rpmcliProgressTotal = 1;
 	rpmcliProgressCurrent = 0;
-	if (!(flags & INSTALL_LABEL))
+	if (!(flags & RPMEIU_LABEL))
 	    break;
-	if (flags & INSTALL_HASH)
+	if (flags & RPMEIU_HASH)
 	    fprintf(stdout, "%-28s", _("Preparing..."));
 	else
 	    fprintf(stdout, "%s\n", _("Preparing packages for installation..."));
@@ -159,7 +159,7 @@ void * rpmShowProgress(const void * arg,
 	break;
 
     case RPMCALLBACK_TRANS_STOP:
-	if (flags & INSTALL_HASH)
+	if (flags & RPMEIU_HASH)
 	    printHash(1, 1);	/* Fixes "preparing..." progress bar */
 	rpmcliProgressTotal = rpmcliPackagesTotal;
 	rpmcliProgressCurrent = 0;
@@ -228,7 +228,7 @@ int rpmInstall(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_t fileArgv)
     probFilter = ia->probFilter;
     relocations = ia->relocations;
 
-    if (ia->installInterfaceFlags & INSTALL_UPGRADE)
+    if (ia->eiuInterfaceFlags & RPMEIU_UPGRADE)
 	vsflags = rpmExpandNumeric("%{?_vsflags_erase}");
     else
 	vsflags = rpmExpandNumeric("%{?_vsflags_install}");
@@ -241,7 +241,7 @@ int rpmInstall(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_t fileArgv)
     ovsflags = rpmtsSetVSFlags(ts, (vsflags | RPMVSF_NEEDPAYLOAD));
 
     {	int notifyFlags;
-	notifyFlags = ia->installInterfaceFlags | (rpmIsVerbose() ? INSTALL_LABEL : 0 );
+	notifyFlags = ia->eiuInterfaceFlags | (rpmIsVerbose() ? RPMEIU_LABEL : 0 );
 	xx = rpmtsSetNotifyCallback(ts,
 			rpmShowProgress, (void *) ((long)notifyFlags));
     }
@@ -415,7 +415,7 @@ restart:
 	}
 
 	/* On --freshen, verify package is installed and newer */
-	if (ia->installInterfaceFlags & INSTALL_FRESHEN) {
+	if (ia->eiuInterfaceFlags & RPMEIU_FRESHEN) {
 	    rpmdbMatchIterator mi;
 	    const char * name;
 	    Header oldH;
@@ -440,7 +440,7 @@ restart:
 	}
 
 	rc = rpmtsAddInstallElement(ts, eiu->h, (fnpyKey)fileName,
-			(ia->installInterfaceFlags & INSTALL_UPGRADE) != 0,
+			(ia->eiuInterfaceFlags & RPMEIU_UPGRADE) != 0,
 			relocations);
 
 	/* XXX reference held by transaction set */
@@ -513,7 +513,7 @@ maybe_manifest:
 
     if (eiu->numFailed) goto exit;
 
-    if (eiu->numRPMS && !(ia->installInterfaceFlags & INSTALL_NODEPS)) {
+    if (eiu->numRPMS && !(ia->eiuInterfaceFlags & RPMEIU_NODEPS)) {
 
 	if (rpmtsCheck(ts)) {
 	    eiu->numFailed = eiu->numPkgs;
@@ -530,7 +530,7 @@ maybe_manifest:
 	ps = rpmpsFree(ps);
     }
 
-    if (eiu->numRPMS && !(ia->installInterfaceFlags & INSTALL_NOORDER)) {
+    if (eiu->numRPMS && !(ia->eiuInterfaceFlags & RPMEIU_NOORDER)) {
 	if (rpmtsOrder(ts)) {
 	    eiu->numFailed = eiu->numPkgs;
 	    stopInstall = 1;
@@ -632,7 +632,7 @@ int rpmErase(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_const_t argv)
 
 #ifdef	NOTYET	/* XXX no callbacks on erase yet */
     {	int notifyFlags, xx;
-	notifyFlags = ia->eraseInterfaceFlags | (rpmIsVerbose() ? INSTALL_LABEL : 0 );
+	notifyFlags = ia->eiuInterfaceFlags | (rpmIsVerbose() ? RPMEIU_LABEL : 0 );
 	xx = rpmtsSetNotifyCallback(ts,
 			rpmShowProgress, (void *) ((long)notifyFlags));
     }
@@ -658,7 +658,7 @@ int rpmErase(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_const_t argv)
 	    Header h;	/* XXX iterator owns the reference */
 
 	    if (matches > 1 && 
-		!(ia->eraseInterfaceFlags & UNINSTALL_ALLMATCHES)) {
+		!(ia->eiuInterfaceFlags & RPMEIU_ALLMATCHES)) {
 		rpmlog(RPMLOG_ERR, _("\"%s\" specifies multiple packages:\n"),
 			*arg);
 		numFailed++;
@@ -684,7 +684,7 @@ int rpmErase(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_const_t argv)
 
     if (numFailed) goto exit;
 
-    if (!(ia->eraseInterfaceFlags & UNINSTALL_NODEPS)) {
+    if (!(ia->eiuInterfaceFlags & RPMEIU_NODEPS)) {
 
 	if (rpmtsCheck(ts)) {
 	    numFailed = numPackages;
@@ -701,7 +701,7 @@ int rpmErase(rpmts ts, struct rpmInstallArguments_s * ia, ARGV_const_t argv)
 	ps = rpmpsFree(ps);
     }
 
-    if (!stopUninstall && !(ia->installInterfaceFlags & INSTALL_NOORDER)) {
+    if (!stopUninstall && !(ia->eiuInterfaceFlags & RPMEIU_NOORDER)) {
 	if (rpmtsOrder(ts)) {
 	    numFailed += numPackages;
 	    stopUninstall = 1;
diff --git a/rpmqv.c b/rpmqv.c
index a9ec074..cc8c730 100644
--- a/rpmqv.c
+++ b/rpmqv.c
@@ -354,9 +354,9 @@ int main(int argc, char *argv[])
 
 #ifdef	IAM_RPMEIU
   if (bigMode == MODE_UNKNOWN || (bigMode & MODES_IE))
-    {	int iflags = (ia->installInterfaceFlags &
-		(INSTALL_UPGRADE|INSTALL_FRESHEN|INSTALL_INSTALL));
-	int eflags = (ia->installInterfaceFlags & INSTALL_ERASE);
+    {	int iflags = (ia->eiuInterfaceFlags &
+		(RPMEIU_UPGRADE|RPMEIU_FRESHEN|RPMEIU_INSTALL));
+	int eflags = (ia->eiuInterfaceFlags & RPMEIU_ERASE);
 
 	if (iflags & eflags)
 	    argerror(_("only one major mode may be specified"));
@@ -407,11 +407,11 @@ int main(int argc, char *argv[])
     if (ia->prefix && ia->prefix[0] != '/') 
 	argerror(_("arguments to --prefix must begin with a /"));
 
-    if (bigMode != MODE_INSTALL && (ia->installInterfaceFlags & INSTALL_HASH))
+    if (bigMode != MODE_INSTALL && (ia->eiuInterfaceFlags & RPMEIU_HASH))
 	argerror(_("--hash (-h) may only be specified during package "
 			"installation"));
 
-    if (bigMode != MODE_INSTALL && (ia->installInterfaceFlags & INSTALL_PERCENT))
+    if (bigMode != MODE_INSTALL && (ia->eiuInterfaceFlags & RPMEIU_PERCENT))
 	argerror(_("--percent may only be specified during package "
 			"installation"));
 
@@ -444,7 +444,7 @@ int main(int argc, char *argv[])
 	argerror(_("--ignoresize may only be specified during package "
 		   "installation"));
 
-    if ((ia->eraseInterfaceFlags & UNINSTALL_ALLMATCHES) && bigMode != MODE_ERASE)
+    if ((ia->eiuInterfaceFlags & RPMEIU_ALLMATCHES) && bigMode != MODE_ERASE)
 	argerror(_("--allmatches may only be specified during package "
 		   "erasure"));
 
@@ -708,7 +708,7 @@ int main(int argc, char *argv[])
 
 #ifdef	IAM_RPMEIU
     case MODE_ERASE:
-	if (ia->noDeps) ia->eraseInterfaceFlags |= UNINSTALL_NODEPS;
+	if (ia->noDeps) ia->eiuInterfaceFlags |= RPMEIU_NODEPS;
 
 	if (!poptPeekArg(optCon)) {
 	    argerror(_("no packages given for erase"));
@@ -728,7 +728,7 @@ int main(int argc, char *argv[])
 		ia->transFlags |= RPMTRANS_FLAG_NODOCS;
 	}
 
-	if (ia->noDeps) ia->installInterfaceFlags |= INSTALL_NODEPS;
+	if (ia->noDeps) ia->eiuInterfaceFlags |= RPMEIU_NODEPS;
 
 	/* we've already ensured !(!ia->prefix && !ia->relocations) */
 	if (ia->prefix) {

diff --git a/lib/rpmcli.h b/lib/rpmcli.h
index 0754629..a058577 100644
--- a/lib/rpmcli.h
+++ b/lib/rpmcli.h
@@ -345,29 +345,21 @@ extern struct poptOption		rpmBuildPoptTable[];
 /* --- install/upgrade/erase modes */
 
 /** \ingroup rpmcli
- * Bit(s) to control rpmInstall() operation.
- */
-typedef enum rpmInstallInterfaceFlags_e {
-    INSTALL_NONE	= 0,
-    INSTALL_PERCENT	= (1 << 0),	/*!< from --percent */
-    INSTALL_HASH	= (1 << 1),	/*!< from --hash */
-    INSTALL_NODEPS	= (1 << 2),	/*!< from --nodeps */
-    INSTALL_NOORDER	= (1 << 3),	/*!< from --noorder */
-    INSTALL_LABEL	= (1 << 4),	/*!< from --verbose (notify) */
-    INSTALL_UPGRADE	= (1 << 5),	/*!< from --upgrade */
-    INSTALL_FRESHEN	= (1 << 6),	/*!< from --freshen */
-    INSTALL_INSTALL	= (1 << 7),	/*!< from --install */
-    INSTALL_ERASE	= (1 << 8)	/*!< from --erase */
-} rpmInstallInterfaceFlags;
-
-/** \ingroup rpmcli
- * Bit(s) to control rpmErase() operation.
- */
-typedef enum rpmEraseInterfaceFlags_e {
-    UNINSTALL_NONE	= 0,
-    UNINSTALL_NODEPS	= (1 << 0),	/*!< from --nodeps */
-    UNINSTALL_ALLMATCHES= (1 << 1)	/*!< from --allmatches */
-} rpmEraseInterfaceFlags;
+ * Bit(s) to control rpmInstall() and rpmErase() operation.
+ */
+typedef enum rpmEIUInterfaceFlags_e {
+    RPMEIU_NONE	= 0,
+    RPMEIU_PERCENT	= (1 << 0),	/*!< from --percent */
+    RPMEIU_HASH	= (1 << 1),	/*!< from --hash */
+    RPMEIU_NODEPS	= (1 << 2),	/*!< from --nodeps */
+    RPMEIU_NOORDER	= (1 << 3),	/*!< from --noorder */
+    RPMEIU_LABEL	= (1 << 4),	/*!< from --verbose (notify) */
+    RPMEIU_UPGRADE	= (1 << 5),	/*!< from --upgrade */
+    RPMEIU_FRESHEN	= (1 << 6),	/*!< from --freshen */
+    RPMEIU_INSTALL	= (1 << 7),	/*!< from --install */
+    RPMEIU_ERASE	= (1 << 8),	/*!< from --erase */
+    RPMEIU_ALLMATCHES= (1 << 1)	        /*!< from --allmatches */
+} rpmEIUInterfaceFlags;
 
 extern int rpmcliPackagesTotal;
 extern int rpmcliHashesCurrent;
@@ -386,7 +378,7 @@ extern int rpmcliProgressTotal;
  * @param amount	per-callback progress info
  * @param total		per-callback progress info
  * @param key		opaque header key (e.g. file name or PyObject)
  * @param data		private data (e.g. rpmInstallInterfaceFlags)
  * @return		per-callback data (e.g. an opened FD_t)
  */
 void * rpmShowProgress(const void * arg,
@@ -415,8 +407,7 @@ int rpmInstallSource(rpmts ts, const char * arg,
 struct rpmInstallArguments_s {
     rpmtransFlags transFlags;
     rpmprobFilterFlags probFilter;
-    rpmInstallInterfaceFlags installInterfaceFlags;
-    rpmEraseInterfaceFlags eraseInterfaceFlags;
+    rpmEIUInterfaceFlags eiuInterfaceFlags;
     rpmQueryFlags qva_flags;	/*!< from --nodigest/--nosignature */
     int numRelocations;
     int noDeps;
@@ -386,7 +378,7 @@ extern int rpmcliProgressTotal;
  * @param total		per-callback progress info
  * @param key		opaque header key (e.g. file name or PyObject)
- * @param data		private data (e.g. rpmInstallInterfaceFlags)
+ * @param data		private data (e.g. rpmEIUInterfaceFlags)
  * @return		per-callback data (e.g. an opened FD_t)
  */